@@ -36,9 +36,12 @@ static char RCSId[]="$Id: stats.c,v 1.0 1996/01/01 16:44:17 david Rel $";
 #include <string.h>
 #include <time.h>
 #include <limits.h>
+#include <error.h>
 
 #include "uutraf.h"
 
+extern int errno;
+
 void ReadStatsfile(char *statsfilename)
 /*
  * Reads in the stats file and builds a linked list of lines, containing
